Interface: PointPrefixedHoverOptions | Chart.js
Description: Open source HTML5 Charts for your website

# # Interface: PointPrefixedHoverOptions

## # Properties

### # pointHoverBackgroundColor

• pointHoverBackgroundColor: `Color`

Point background color when hovered.

#### # Defined in

index.esm.d.ts:1950
(opens new window)

### # pointHoverBorderColor

• pointHoverBorderColor: `Color`

Point border color when hovered.

#### # Defined in

index.esm.d.ts:1954
(opens new window)

### # pointHoverBorderWidth

• pointHoverBorderWidth: `number`

Border width of point when hovered.

#### # Defined in

index.esm.d.ts:1958
(opens new window)

### # pointHoverRadius

• pointHoverRadius: `number`

The radius of the point when hovered.

#### # Defined in

index.esm.d.ts:1962
(opens new window)